@@ -4,12 +4,16 @@ from typing import Final
 
 from ecowitt2mqtt.helpers.typing import UnitSystemType
 
+__version__ = "2022.06.3"
+
+
 LOGGER = logging.getLogger(__package__)
 
 # Configuration keys:
 CONF_BATTERY_OVERRIDES: Final = "battery_override"
 CONF_CONFIG: Final = "config"
 CONF_DEFAULT_BATTERY_STRATEGY: Final = "default_battery_strategy"
+CONF_DIAGNOSTICS: Final = "diagnostics"
 CONF_ENDPOINT: Final = "endpoint"
 CONF_HASS_DISCOVERY: Final = "hass_discovery"
 CONF_HASS_DISCOVERY_PREFIX: Final = "hass_discovery_prefix"
@@ -18,6 +22,7 @@ CONF_INPUT_UNIT_SYSTEM: Final = "input_unit_system"
 CONF_MQTT_BROKER: Final = "mqtt_broker"
 CONF_MQTT_PASSWORD: Final = "mqtt_password"
 CONF_MQTT_PORT: Final = "mqtt_port"
+CONF_MQTT_TLS: Final = "mqtt_tls"
 CONF_MQTT_TOPIC: Final = "mqtt_topic"
 CONF_MQTT_USERNAME: Final = "mqtt_username"
 CONF_OUTPUT_UNIT_SYSTEM: Final = "output_unit_system"
@@ -40,8 +45,17 @@ DATA_POINT_GLOB_WIND: Final = "wind"
 DATA_POINT_GLOB_WINDDIR: Final = "winddir"
 
 # Data points (specific):
+DATA_POINT_BATTERY1: Final = "batt1"
+DATA_POINT_BATTERY2: Final = "batt2"
+DATA_POINT_BATTERY3: Final = "batt3"
+DATA_POINT_BATTERY4: Final = "batt4"
+DATA_POINT_BATTERY5: Final = "batt5"
+DATA_POINT_BATTERY6: Final = "batt6"
+DATA_POINT_BATTERY7: Final = "batt7"
+DATA_POINT_BATTERY8: Final = "batt8"
 DATA_POINT_CO2: Final = "co2"
 DATA_POINT_CO2_24H: Final = "co2_24h"
+DATA_POINT_CO2_BATT: Final = "co2_batt"
 DATA_POINT_DAILY_RAIN: Final = "dailyrain"
 DATA_POINT_DEWPOINT: Final = "dewpoint"
 DATA_POINT_EVENT_RAIN: Final = "eventrain"
@@ -50,11 +64,35 @@ DATA_POINT_HEATINDEX: Final = "heatindex"
 DATA_POINT_HOURLY_RAIN: Final = "hourlyrain"
 DATA_POINT_HUMIDITY: Final = "humidity"
 DATA_POINT_HUMI_CO2: Final = "humi_co2"
+DATA_POINT_LEAKBATT1: Final = "leakbatt1"
+DATA_POINT_LEAKBATT2: Final = "leakbatt2"
+DATA_POINT_LEAKBATT3: Final = "leakbatt3"
+DATA_POINT_LEAKBATT4: Final = "leakbatt4"
+DATA_POINT_LEAKBATT5: Final = "leakbatt5"
+DATA_POINT_LEAKBATT6: Final = "leakbatt6"
+DATA_POINT_LEAKBATT7: Final = "leakbatt7"
+DATA_POINT_LEAKBATT8: Final = "leakbatt8"
 DATA_POINT_LIGHTNING: Final = "lightning"
 DATA_POINT_LIGHTNING_NUM: Final = "lightning_num"
 DATA_POINT_LIGHTNING_TIME: Final = "lightning_time"
 DATA_POINT_MONTHLY_RAIN: Final = "monthlyrain"
+DATA_POINT_PM25BATT1: Final = "pm25batt1"
+DATA_POINT_PM25BATT2: Final = "pm25batt2"
+DATA_POINT_PM25BATT3: Final = "pm25batt3"
+DATA_POINT_PM25BATT4: Final = "pm25batt4"
+DATA_POINT_PM25BATT5: Final = "pm25batt5"
+DATA_POINT_PM25BATT6: Final = "pm25batt6"
+DATA_POINT_PM25BATT7: Final = "pm25batt7"
+DATA_POINT_PM25BATT8: Final = "pm25batt8"
 DATA_POINT_RUNTIME: Final = "runtime"
+DATA_POINT_SOILBATT1: Final = "soilbatt1"
+DATA_POINT_SOILBATT2: Final = "soilbatt2"
+DATA_POINT_SOILBATT3: Final = "soilbatt3"
+DATA_POINT_SOILBATT4: Final = "soilbatt4"
+DATA_POINT_SOILBATT5: Final = "soilbatt5"
+DATA_POINT_SOILBATT6: Final = "soilbatt6"
+DATA_POINT_SOILBATT7: Final = "soilbatt7"
+DATA_POINT_SOILBATT8: Final = "soilbatt8"
 DATA_POINT_SOLARRADIATION: Final = "solarradiation"
 DATA_POINT_SOLARRADIATION_LUX: Final = "solarradiation_lux"
 DATA_POINT_SOLARRADIATION_PERCEIVED: Final = "solarradiation_perceived"
@@ -63,14 +101,33 @@ DATA_POINT_TF_CO2: Final = "tf_co2"
 DATA_POINT_TOTAL_RAIN: Final = "totalrain"
 DATA_POINT_UV: Final = "uv"
 DATA_POINT_WEEKLY_RAIN: Final = "weeklyrain"
+DATA_POINT_WH25BATT: Final = "wh25batt"
+DATA_POINT_WH26BATT: Final = "wh26batt"
+DATA_POINT_WH40BATT: Final = "wh40batt"
+DATA_POINT_WH57BATT: Final = "wh57batt"
+DATA_POINT_WH65BATT: Final = "wh65batt"
+DATA_POINT_WH68BATT: Final = "wh68batt"
+DATA_POINT_WH80BATT: Final = "wh80batt"
+DATA_POINT_WH90BATT: Final = "wh90batt"
+DATA_POINT_WH90BATT_PC: Final = "wh90battpc"
+DATA_POINT_WH90CAP_VOLT: Final = "ws90cap_volt"
 DATA_POINT_WINDCHILL: Final = "windchill"
 DATA_POINT_WINDSPEEDMPH: Final = "windspeedmph"
+DATA_POINT_WN34BATT1: Final = "tf_batt1"
+DATA_POINT_WN34BATT2: Final = "tf_batt2"
+DATA_POINT_WN34BATT3: Final = "tf_batt3"
+DATA_POINT_WN34BATT4: Final = "tf_batt4"
+DATA_POINT_WN34BATT5: Final = "tf_batt5"
+DATA_POINT_WN34BATT6: Final = "tf_batt6"
+DATA_POINT_WN34BATT7: Final = "tf_batt7"
+DATA_POINT_WN34BATT8: Final = "tf_batt8"
 DATA_POINT_YEARLY_RAIN: Final = "yearlyrain"
 
 # Environment variables:
 ENV_BATTERY_OVERRIDE: Final = "ECOWITT2MQTT_BATTERY_OVERRIDE"
 ENV_CONFIG: Final = "ECOWITT2MQTT_CONFIG"
 ENV_DEFAULT_BATTERY_STRATEGY: Final = "ECOWITT2MQTT_DEFAULT_BATTERY_STRATEGY"
+ENV_DIAGNOSTICS: Final = "ECOWITT2MQTT_DIAGNOSTICS"
 ENV_ENDPOINT: Final = "ECOWITT2MQTT_ENDPOINT"
 ENV_HASS_DISCOVERY: Final = "ECOWITT2MQTT_HASS_DISCOVERY"
 ENV_HASS_DISCOVERY_PREFIX: Final = "ECOWITT2MQTT_HASS_DISCOVERY_PREFIX"
@@ -79,6 +136,7 @@ ENV_INPUT_UNIT_SYSTEM: Final = "ECOWITT2MQTT_INPUT_UNIT_SYSTEM"
 ENV_MQTT_BROKER: Final = "ECOWITT2MQTT_MQTT_BROKER"
 ENV_MQTT_PASSWORD: Final = "ECOWITT2MQTT_MQTT_PASSWORD"
 ENV_MQTT_PORT: Final = "ECOWITT2MQTT_MQTT_PORT"
+ENV_MQTT_TLS: Final = "ECOWITT2MQTT_MQTT_TLS"
 ENV_MQTT_TOPIC: Final = "ECOWITT2MQTT_MQTT_TOPIC"
 ENV_MQTT_USERNAME: Final = "ECOWITT2MQTT_MQTT_USERNAME"
 ENV_OUTPUT_UNIT_SYSTEM: Final = "ECOWITT2MQTT_OUTPUT_UNIT_SYSTEM"
