@@ -48,7 +48,10 @@ from ecowitt2mqtt.const import (
 from ecowitt2mqtt.data import ProcessedData
 from ecowitt2mqtt.errors import EcowittError
 from ecowitt2mqtt.helpers.calculator import CalculatedDataPoint
-from ecowitt2mqtt.helpers.calculator.battery import BatteryStrategy, BooleanBatteryState
+from ecowitt2mqtt.helpers.calculator.battery import (
+    BatteryStrategy,
+    get_battery_strategy,
+)
 from ecowitt2mqtt.helpers.device import Device
 from ecowitt2mqtt.helpers.publisher import (
     MqttPublisher,
@@ -119,7 +122,6 @@ class DeviceType(TypedDict):
 class EntityDescription:
     """Define a description (set of characteristics) of a Home Assistant entity."""
 
-    platform: str
     device_class: str | None = None
     entity_category: str | None = None
     icon: str | None = None
@@ -134,157 +136,133 @@ class HassDiscoveryPayload:
     topic: str
 
 
-DATA_POINT_BINARY_BATTERY = "binary_battery"
-DATA_POINT_NUMERIC_BATTERY = "numeric_battery"
+DATA_POINT_BATTERY_BOOLEAN = "battery_boolean"
+DATA_POINT_BATTERY_NUMERIC = "battery_numeric"
+DATA_POINT_BATTERY_PERCENTAGE = "battery_percentage"
 
 ENTITY_DESCRIPTIONS = {
-    DATA_POINT_BINARY_BATTERY: EntityDescription(
-        platform=Platform.BINARY_SENSOR,
+    DATA_POINT_BATTERY_BOOLEAN: EntityDescription(
+        device_class=DeviceClass.BATTERY,
+        entity_category=EntityCategory.DIAGNOSTIC,
+    ),
+    DATA_POINT_BATTERY_NUMERIC: EntityDescription(
+        device_class=DeviceClass.VOLTAGE,
+        entity_category=EntityCategory.DIAGNOSTIC,
+        state_class=StateClass.MEASUREMENT,
+    ),
+    DATA_POINT_BATTERY_PERCENTAGE: EntityDescription(
         device_class=DeviceClass.BATTERY,
         entity_category=EntityCategory.DIAGNOSTIC,
         state_class=StateClass.MEASUREMENT,
     ),
     DATA_POINT_GLOB_BAROM: EntityDescription(
-        platform=Platform.SENSOR,
         device_class=DeviceClass.PRESSURE,
         state_class=StateClass.MEASUREMENT,
     ),
     DATA_POINT_GLOB_GUST: EntityDescription(
-        platform=Platform.SENSOR,
         icon="mdi:weather-windy",
         state_class=StateClass.MEASUREMENT,
     ),
     DATA_POINT_GLOB_HUMIDITY: EntityDescription(
-        platform=Platform.SENSOR,
         device_class=DeviceClass.HUMIDITY,
         state_class=StateClass.MEASUREMENT,
     ),
     DATA_POINT_GLOB_MOISTURE: EntityDescription(
-        platform=Platform.SENSOR,
         icon="mdi:water-percent",
         state_class=StateClass.MEASUREMENT,
     ),
     DATA_POINT_GLOB_PM10: EntityDescription(
-        platform=Platform.SENSOR,
         device_class=DeviceClass.PM10,
         state_class=StateClass.MEASUREMENT,
     ),
     DATA_POINT_GLOB_PM25: EntityDescription(
-        platform=Platform.SENSOR,
         device_class=DeviceClass.PM25,
         state_class=StateClass.MEASUREMENT,
     ),
     DATA_POINT_GLOB_RAIN: EntityDescription(
-        platform=Platform.SENSOR,
         icon="mdi:water",
         state_class=StateClass.MEASUREMENT,
     ),
     DATA_POINT_GLOB_TEMP: EntityDescription(
-        platform=Platform.SENSOR,
         device_class=DeviceClass.TEMPERATURE,
         state_class=StateClass.MEASUREMENT,
     ),
     DATA_POINT_GLOB_VOLT: EntityDescription(
-        platform=Platform.SENSOR,
         device_class=DeviceClass.VOLTAGE,
         state_class=StateClass.MEASUREMENT,
     ),
     DATA_POINT_GLOB_WIND: EntityDescription(
-        platform=Platform.SENSOR,
         icon="mdi:weather-windy",
         state_class=StateClass.MEASUREMENT,
     ),
     DATA_POINT_GLOB_WINDDIR: EntityDescription(
-        platform=Platform.SENSOR,
         icon="mdi:compass",
     ),
     DATA_POINT_CO2: EntityDescription(
-        platform=Platform.SENSOR,
         device_class=DeviceClass.CO2,
         state_class=StateClass.MEASUREMENT,
     ),
     DATA_POINT_CO2_24H: EntityDescription(
-        platform=Platform.SENSOR,
         device_class=DeviceClass.CO2,
         state_class=StateClass.MEASUREMENT,
     ),
     DATA_POINT_DEWPOINT: EntityDescription(
-        platform=Platform.SENSOR,
         device_class=DeviceClass.TEMPERATURE,
         state_class=StateClass.MEASUREMENT,
     ),
     DATA_POINT_FEELSLIKE: EntityDescription(
-        platform=Platform.SENSOR,
         device_class=DeviceClass.TEMPERATURE,
         state_class=StateClass.MEASUREMENT,
     ),
     DATA_POINT_HEATINDEX: EntityDescription(
-        platform=Platform.SENSOR,
         device_class=DeviceClass.TEMPERATURE,
         state_class=StateClass.MEASUREMENT,
     ),
     DATA_POINT_HUMI_CO2: EntityDescription(
-        platform=Platform.SENSOR,
         device_class=DeviceClass.HUMIDITY,
         state_class=StateClass.MEASUREMENT,
     ),
     DATA_POINT_LIGHTNING: EntityDescription(
-        platform=Platform.SENSOR,
         icon="mdi:map-marker-distance",
         state_class=StateClass.MEASUREMENT,
     ),
     DATA_POINT_LIGHTNING_NUM: EntityDescription(
-        platform=Platform.SENSOR,
         icon="mdi:weather-lightning",
         state_class=StateClass.TOTAL,
     ),
     DATA_POINT_LIGHTNING_TIME: EntityDescription(
-        platform=Platform.SENSOR,
         device_class=DeviceClass.TIMESTAMP,
         state_class=StateClass.MEASUREMENT,
     ),
     DATA_POINT_SOLARRADIATION: EntityDescription(
-        platform=Platform.SENSOR,
         device_class=DeviceClass.ILLUMINANCE,
         state_class=StateClass.MEASUREMENT,
     ),
     DATA_POINT_SOLARRADIATION_LUX: EntityDescription(
-        platform=Platform.SENSOR,
         device_class=DeviceClass.ILLUMINANCE,
         state_class=StateClass.MEASUREMENT,
     ),
     DATA_POINT_SOLARRADIATION_PERCEIVED: EntityDescription(
-        platform=Platform.SENSOR,
         device_class=DeviceClass.ILLUMINANCE,
         state_class=StateClass.MEASUREMENT,
     ),
     DATA_POINT_RUNTIME: EntityDescription(
-        platform=Platform.SENSOR,
         device_class=DeviceClass.DURATION,
         icon="mdi:timer",
         state_class=StateClass.MEASUREMENT,
     ),
     DATA_POINT_TF_CO2: EntityDescription(
-        platform=Platform.SENSOR,
         device_class=DeviceClass.TEMPERATURE,
         state_class=StateClass.MEASUREMENT,
     ),
     DATA_POINT_UV: EntityDescription(
-        platform=Platform.SENSOR,
         icon="mdi:weather-sunny",
         state_class=StateClass.MEASUREMENT,
     ),
     DATA_POINT_WINDCHILL: EntityDescription(
-        platform=Platform.SENSOR,
         device_class=DeviceClass.TEMPERATURE,
         state_class=StateClass.MEASUREMENT,
     ),
-    DATA_POINT_NUMERIC_BATTERY: EntityDescription(
-        platform=Platform.SENSOR,
-        device_class=DeviceClass.VOLTAGE,
-        entity_category=EntityCategory.DIAGNOSTIC,
-        state_class=StateClass.MEASUREMENT,
-    ),
 }
 
 STATE_CLASS_OVERRIDES = {
@@ -310,17 +288,19 @@ class HomeAssistantDiscoveryPublisher(MqttPublisher):
         self, device: Device, key: str, data_point: CalculatedDataPoint
     ) -> HassDiscoveryPayload:
         """Generate a discovery payload for an entity."""
-        # Since batteries can be either boolean or numeric depending on their
-        # strategy, we calculate an entity description at runtime:
-        if data_point.data_point_key == DATA_POINT_GLOB_BATT:
-            if (
-                isinstance(data_point.unit, BooleanBatteryState)
-                or self.ecowitt.config.default_battery_strategy
-                == BatteryStrategy.BOOLEAN
-            ):
-                data_point_key = DATA_POINT_BINARY_BATTERY
+        platform = Platform.SENSOR
+
+        # Since batteries can be one of many different strategies, we calculate an
+        # entity description at runtime:
+        if data_point.data_point_key in (DATA_POINT_GLOB_BATT, DATA_POINT_GLOB_VOLT):
+            strategy = get_battery_strategy(self.ecowitt, key)
+            if strategy == BatteryStrategy.BOOLEAN:
+                data_point_key = DATA_POINT_BATTERY_BOOLEAN
+                platform = Platform.BINARY_SENSOR
+            elif strategy == BatteryStrategy.NUMERIC:
+                data_point_key = DATA_POINT_BATTERY_NUMERIC
             else:
-                data_point_key = DATA_POINT_NUMERIC_BATTERY
+                data_point_key = DATA_POINT_BATTERY_PERCENTAGE
         else:
             data_point_key = data_point.data_point_key
 
@@ -333,8 +313,8 @@ class HomeAssistantDiscoveryPublisher(MqttPublisher):
             name = key
 
         base_topic = (
-            f"{self.ecowitt.config.hass_discovery_prefix}/{description.platform}/"
-            f"{device.unique_id}/{key}"
+            f"{self.ecowitt.config.hass_discovery_prefix}/{platform}/{device.unique_id}"
+            f"/{key}"
         )
 
         payload = self._discovery_payloads[key] = HassDiscoveryPayload(
@@ -381,7 +361,7 @@ class HomeAssistantDiscoveryPublisher(MqttPublisher):
                     processed_data.device, key, data_point
                 )
             except HassError as err:
-                LOGGER.warning("Skipping %s due to error: %s", key, err)
+                LOGGER.warning('Skipping "%s" due to error: %s', key, err)
                 continue
 
             for topic, payload in (
